@@ -2,10 +2,12 @@ __all__ = [
     'Cutter',
     'Dearrayer',
     'preprocess'
+    'TileLabeler'
 ]
 
 from ._cutter import Cutter
 from ._dearrayer import Dearrayer
+from ._labeler import TileLabeler
 from . import preprocess
 
 from ._version import __version__
