@@ -416,7 +416,7 @@ def save_tile(
         reader = OpenSlide(slide_path)
     (x, y), bg_estimate = coords
     # Prepare filename.
-    filepath = join(image_dir, f'{slide_name}_x-{x}_y-{y}')
+    filepath = join(image_dir, f'x-{x}_y-{y}')
     if image_format == 'png':
         filepath = filepath + '.png'
     else:
@@ -442,5 +442,6 @@ def save_tile(
     if custom_preprocess is not None:
         metadata.update(custom_preprocess(image))
     # Save image.
-    image.save(filepath, quality=quality)
+    if not exists(filepath):
+        image.save(filepath, quality=quality)
     return metadata
